@@ -9,10 +9,9 @@ Paginator <- R6::R6Class("Paginator",
       results <- list()
       start_index <- 0
 
-      params <- list(
-        "startIndex" = 0,
-        "itemsPerPage" = items_per_page
-      )
+      if (!is.null(limit) && limit < items_per_page) {
+        items_per_page <- limit
+      }
 
       tryCatch(
         {
@@ -26,7 +25,7 @@ Paginator <- R6::R6Class("Paginator",
               }
             }
 
-            if ((!is.null(limit) && length(results) > limit) ||
+            if ((!is.null(limit) && length(results) >= limit) ||
               length(results) >= resp$properties$totalResults || length(results) == 0) {
               break
             }
@@ -47,16 +46,17 @@ Paginator <- R6::R6Class("Paginator",
     client = NULL,
     request_type = NULL,
     get_page = function(request, start_index = 0, items_per_page = 10) {
-      params <- list(
-        "startIndex" = start_index,
-        "itemsPerPage" = items_per_page
-      )
 
       req <- request
       if (private$request_type == "POST") {
         req <- req %>%
-          httr2::req_body_json_modify(params)
+          httr2::req_body_json_modify(startIndex = start_index,
+                                      itemsPerPage = items_per_page)
       } else {
+        params <- list(
+          startIndex = start_index,
+          itemsPerPage = items_per_page
+        )
         req <- req %>%
           httr2::req_url_query(!!!params)
       }
